<template>
    <div>
        <el-dialog
            title="选择预算项目"
            :visible.sync="dialogVisible"
            width="70%"
            top="5vh"
            :before-close="dialogBeforeClose"
        >
            <div>
                <div>
                    <el-form ref="searchForm" :model="searchForm" label-width="80px">
                        <el-row :gutter="10" style="display: flex">
                            <el-col :span="5.5">
                                <el-form-item label="年份">
                                    <el-date-picker
                                        v-model="searchForm['b.ASCRIPTION_YEAR_']"
                                        type="year"
                                        value-format="yyyy"
                                        @change="changeYear"
                                        placeholder="date"
                                    ></el-date-picker>
                                </el-form-item>
                            </el-col>
                            <el-col :span="5.5">
                                <el-form-item label="名称">
                                    <el-input
                                        placeholder="请输入名称"
                                        v-model="searchForm['a.BUDGET_CONTENT_']"
                                    ></el-input>
                                </el-form-item>
                            </el-col>
                            <el-col :span="6">
                                <el-button size="small" @click="findinfo" type="primary"
                                    >查询</el-button
                                >
                                <el-button size="small" @click="handleReset" type="plain"
                                    >重置</el-button
                                >
                            </el-col>
                        </el-row>
                    </el-form>
                </div>
                <el-table
                    border
                    size="mini"
                    v-loading="loading"
                    ref="multipleSelection"
                    :data="tableData"
                    :style="{width: '100%'}"
                    height="400px"
                    row-key="getRowKeys"
                    @row-click="handleRowclick"
                    highlight-selection-row
                    :header-cell-style="{'text-align': 'center'}"
                    @selection-change="handleSelectionChange"
                >
                    <el-table-column type="selection" width="55"></el-table-column>

                    <el-table-column
                        prop="budgetTypeName"
                        label="预算分类"
                        align="center"
                        min-width="80"
                    ></el-table-column>
                    <el-table-column
                        prop="budgetItemName"
                        label="预算项目"
                        align="center"
                        min-width="80"
                    ></el-table-column>
                    <el-table-column
                        prop="totalPrice"
                        label="预算金额(万元)"
                        align="center"
                        min-width="80"
                    ></el-table-column>
                    <el-table-column
                        prop="budgetContent"
                        label="项目内容"
                        align="left"
                        min-width="160"
                    >
                    </el-table-column>
                </el-table>
                <el-pagination
                    ref="paginationPanel"
                    align="right"
                    class="bbsl-pagination"
                    background
                    @size-change="handleSizeChange"
                    @current-change="handleCurrentChange"
                    :current-page="queryParam.pageBean.page"
                    :page-sizes="[20, 50, 200, , 500]"
                    :page-size="queryParam.pageBean.pageSize"
                    layout="total, sizes, prev, pager, next, jumper"
                    :total="queryParam.pageBean.total"
                ></el-pagination>
            </div>
            <div slot="footer">
                <el-button @click="dialogBeforeClose">取 消</el-button>
                <el-button type="primary" @click="save">确 定</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import basicData from '@/api/basicData.js'
export default {
    data() {
        return {
            dialogVisible: false,
            searchForm: {
                'b.ASCRIPTION_YEAR_': '',
                'b.ROAD_SEGMENT_ID_': '',
            },
            loading: false,
            tableData: [],
            multipleSelection: [],
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                },
            },
            params: {},
            type: '',
            subscribeData: [],
            budgetIds: [],
            typeList: [],
        }
    },
    created() {
        this.$nextTick(() => {
            this.getCostType()
            this.getTypeList()
        })
    },
    mounted() {
        let date = new Date()
        this.searchForm['b.ASCRIPTION_YEAR_'] = date.getFullYear().toString()
    },
    methods: {
        open(row, budgetIds, type) {
            console.log(row, 'row')
            this.dialogVisible = true
            this.params = row
            this.type = type
            this.searchForm['b.ROAD_SEGMENT_ID_'] = this.params.roadSegmentId
            this.searchForm['a.budget_item_'] = 'RCYH' // 'RCJF'

            this.getData()
            if (budgetIds) {
                this.budgetIds = budgetIds
            }
        },
        dialogBeforeClose() {
            this.dialogVisible = false
        },
        findinfo() {
            this.getData()
        },
        handleReset() {
            let date = new Date()
            this.searchForm['b.ASCRIPTION_YEAR_'] = date.getFullYear().toString()
            this.searchForm['b.ROAD_SEGMENT_ID_'] = this.params.roadSegmentId
            this.searchForm['a.BUDGET_CONTENT_'] = ''
            this.getData()
        },
        changeYear(val) {
            this.searchForm['b.ASCRIPTION_YEAR_'] = val
        },
        handleSelectionChange(val) {
            console.log(val, 'val')
            this.multipleSelection = val.map((item) => {
                return item
            })
        },
        getCostType() {
            this.subscribeData = []
            this.$http
                .get('${yhxt}/bizCourseDetails/v1/get/getByParentId?pCode=FXCBXZC')
                .then((res) => {
                    res.data.forEach((item) => {
                        this.subscribeData.push({
                            code: item.subjectCode,
                            name: item.subjectName,
                        })
                    })
                })
        },
        getTypeList() {
            this.typeList = []
            this.$http
                .get('${yhxt}/bizCourseDetails/v1/get/getByParentId?pCode=RCYHZX')
                .then((res) => {
                    res.data.forEach((item) => {
                        this.typeList.push({
                            code: item.subjectCode,
                            name: item.subjectName,
                        })
                    })
                })
            this.$http
                .get('${yhxt}/bizCourseDetails/v1/get/getByParentId?pCode=RCJF')
                .then((res) => {
                    res.data.forEach((item) => {
                        this.typeList.push({
                            code: item.subjectCode,
                            name: item.subjectName,
                        })
                    })
                })
            this.$http
                .get('${yhxt}/bizCourseDetails/v1/get/getByParentId?pCode=FRCZX')
                .then((res) => {
                    res.data.forEach((item) => {
                        this.typeList.push({
                            code: item.subjectCode,
                            name: item.subjectName,
                        })
                    })
                })
            this.$http
                .get('${yhxt}/bizCourseDetails/v1/get/getByParentId?pCode=FZCXZX')
                .then((res) => {
                    res.data.forEach((item) => {
                        this.typeList.push({
                            code: item.subjectCode,
                            name: item.subjectName,
                        })
                    })
                })
            console.log(this.typeList)
        },
        getQuerysParams() {
            let {searchForm, queryParam} = this
            let {page, pageSize} = queryParam.pageBean
            let querys = []
            for (let i in searchForm) {
                if (i == 'a.budget_item_') {
                    querys.push({
                        group: 'main',
                        operation: 'NOT_EQUAL',
                        property: i,
                        relation: 'AND',
                        value: searchForm[i],
                    })
                } else {
                    querys.push({
                        group: 'main',
                        operation: 'LIKE',
                        property: i,
                        relation: 'AND',
                        value: searchForm[i],
                    })
                }
            }
            return {
                pageBean: {
                    page,
                    pageSize,
                    showTotal: true,
                },
                querys,
            }
        },
        getData() {
            this.loading = true
            this.queryParam = this.getQuerysParams()
            this.tableData = []
            this.$http
                .post('${yhxt}/yearBudgetDetailed/v1/getJsonForProject', this.queryParam)
                .then((res) => {
                    this.loading = false
                    this.queryParam.pageBean.total = res.data.total
                    this.queryParam.pageBean.page = res.data.page
                    this.queryParam.pageBean.pageSize = res.data.pageSize
                    this.tableData = res.data.rows
                    this.tableData.forEach((item) => {
                        this.subscribeData.forEach((e) => {
                            if (item.budgetType == e.code) {
                                this.$set(item, 'budgetTypeName', e.name)
                            }
                        })
                        this.typeList.forEach((v) => {
                            if (item.budgetItem == v.code) {
                                this.$set(item, 'budgetItemName', v.name)
                            }
                        })
                    })
                    this.$nextTick(() => {
                        if (this.type === 'edit') {
                            this.tableData.forEach((item, index) => {
                                if (this.budgetIds.findIndex((v) => v == item.id) >= 0) {
                                    this.$refs.multipleSelection.toggleRowSelection(
                                        this.$refs.multipleSelection.data[index],
                                        true
                                    )
                                }
                            })
                        }
                    })
                })
        },
        handleRowclick(row) {
            this.$refs.multipleSelection.toggleRowSelection(row)
        },
        save() {
            this.dialogVisible = false
            this.$emit('common', this.multipleSelection)
        },
        handleSizeChange(val) {
            this.queryParam.pageBean.pageSize = val
            this.getData()
        },
        handleCurrentChange(val) {
            this.queryParam.pageBean.page = val
            this.getData()
        },
        getRowKeys(row) {
            return row.id
        },
    },
}
</script>

<style lang="scss" scoped></style>
